/*
 * MAX_NUM_CPUS 16 is already defined in aixget.h
 */
#include "aixget.h"

#define MAX_NUM_NODES 2048     /* 12-bit node ID */
#define MAX_NUM_TASKS 8192     /* there is no limit for MAX_NUM_TASKS */

/*
 * thread Type: system thread, user thread, and MPI thread
 */
#define SYSTEM_THREAD 2
#define USER_THREAD 1
#define MPI_THREAD 0

#define ISBITSET(a,i)  ((a[(i)/8]) &   (1 << (i)%8))
#define SETBIT(a,i) ((a[(i)/8]) |=  (1 << (i)%8))
#define CLRBIT(a,i) ((a[(i)/8]) &= ~(1 << (i)%8))

/* 
 * tidnode structure is an element in thread list of the hash table 
 */
typedef struct _tidnode {
  int tid;               /* thread id */
  int pid;               /* process id */
  short int cpuid;       /* current cpu id */
  short int active;      /* currently active */
  short int nodeid;      /* node id. threads do not change this */
  short int oldcpu;      /* old CPU ID the thread was running on */
  int ltid;              /* logical thread ID, -1 means */
  struct _tidnode *next; /* next tidNODE in the linked list */
  struct _tidnode *tidnext; /* next tidNODE for recognized threads */
} tidnode;

typedef struct _tasknode {
  int pid;                 /* AIX process ID */
  int taskid;              /* MPI task ID */
  int nthreads;            /* number of threads being recognized */
  tidnode *tidnext;        /* linked list for tidnodes */
  struct _tasknode *back;  
  struct _tasknode *left;
  struct _tasknode *right;
  int bal;
} TASKNODE;

